### What did you do?

### What did you expect to happen?

### What actually happened?

### What versions are you using?

* OS: 
* Python: 
* UltraJSON: 

Please include **code** that reproduces the issue.

The [best reproductions](https://stackoverflow.com/help/minimal-reproducible-example) are [self-contained scripts](https://ericlippert.com/2014/03/05/how-to-debug-small-programs/) with minimal dependencies.

```python
code goes here
```
